@@ -14,17 +14,13 @@ class TrafficItem(CustomField):
     
     """
     _RESULT_COLUMNS = [
-        'name',
-        'state',
-        'port_tx',
-        'port_rx',
-        'frames_tx',
-        'frames_rx',
-        'frames_tx_rate',
-        'frames_rx_rate',
-        'bytes_tx_rate',
-        'bytes_rx_rate',
-        'loss',
+        ('frames_tx', 'Tx Frames', int),
+        ('frames_rx', 'Rx Frames', int),
+        ('frames_tx_rate', 'Tx Frame Rate', float),
+        ('frames_rx_rate', 'Rx Frame Rate', float),
+        ('bytes_tx_rate', 'Tx Rate (Bps)', float),
+        ('bytes_rx_rate', 'Rx Rate (Bps)', float),
+        ('loss', 'Loss %', float)
     ]
 
     _STACK_IGNORE = ['ethernet.fcs']
@@ -167,11 +163,12 @@ class TrafficItem(CustomField):
                 self._configure_endpoint(ixn_traffic_item.EndpointSet,
                                          flow.tx_rx)
                 self._configure_tracking(ixn_traffic_item.Tracking)
-                ixn_stream = ixn_traffic_item.ConfigElement.find()
-                self._configure_stack(ixn_stream, flow.packet)
-                self._configure_size(ixn_stream, flow.size)
-                self._configure_rate(ixn_stream, flow.rate)
-                self._configure_tx_control(ixn_stream, flow.duration)
+                ixn_ce = ixn_traffic_item.ConfigElement.find()
+                hl_stream_count = len(ixn_traffic_item.HighLevelStream.find())
+                self._configure_stack(ixn_ce, flow.packet)
+                self._configure_size(ixn_ce, flow.size)
+                self._configure_rate(ixn_ce, flow.rate)
+                self._configure_tx_control(ixn_ce, hl_stream_count, flow.duration)
                 self._configure_options(flow)
 
     def _configure_tracking(self, ixn_tracking):
@@ -230,7 +227,7 @@ class TrafficItem(CustomField):
             ixn_endpoint_set.add(**args)
         elif ixn_endpoint_set.Sources != args[
                 'Sources'] or ixn_endpoint_set.Destinations != args[
-                    'Destinations']:
+                    'Destinations'] or len(ixn_endpoint_set.parent.ConfigElement.find()) == 0:
             self._update(ixn_endpoint_set, **args)
 
     def _update(self, ixn_object, **kwargs):
@@ -395,7 +392,7 @@ class TrafficItem(CustomField):
         args['Rate'] = rate.value
         self._update(ixn_frame_rate, **args)
 
-    def _configure_tx_control(self, ixn_stream, duration):
+    def _configure_tx_control(self, ixn_stream, hl_stream_count, duration):
         """Transform duration flows.duration to /traffic/trafficItem[*]/configElement[*]/TransmissionControl
         """
         if duration is None:
@@ -409,7 +406,7 @@ class TrafficItem(CustomField):
             args['StartDelayUnits'] = duration.continuous.delay_unit
         elif duration.choice == 'packets':
             args['Type'] = 'fixedFrameCount'
-            args['FrameCount'] = duration.packets.packets
+            args['FrameCount'] = duration.packets.packets / hl_stream_count
             args['MinGapBytes'] = duration.packets.gap
             args['StartDelay'] = duration.packets.delay
             args['StartDelayUnits'] = duration.packets.delay_unit
@@ -450,7 +447,8 @@ class TrafficItem(CustomField):
                 with Timer(self._api, 'Flows generate/apply'):
                     self._api._traffic_item.Generate()
                     self._api._traffic.Apply()
-            if len(self._api._traffic_item) > 0:
+            self._api._traffic_item.find(State='^started$')
+            if len(self._api._traffic_item) == 0:
                 with Timer(self._api, 'Flows clear statistics'):
                     self._api._ixnetwork.ClearStats(
                         ['waitForPortStatsRefresh', 'waitForTrafficStatsRefresh'])
@@ -460,12 +458,12 @@ class TrafficItem(CustomField):
             with Timer(self._api, 'Flows start'):
                 self._api._traffic_item.StartStatelessTrafficBlocking()
         elif request.state == 'stop':
-            self._api._traffic_item.find(Name=regex, State='^started$')
+            self._api._traffic_item.find(Name=regex, State='^start$')
             if len(self._api._traffic_item) > 0:
                 with Timer(self._api, 'Flows stop'):
                     self._api._traffic_item.StopStatelessTrafficBlocking()
         elif request.state == 'pause':
-            self._api._traffic_item.find(Name=regex, State='^started$')
+            self._api._traffic_item.find(Name=regex, State='^start$')
             if len(self._api._traffic_item) > 0:
                 with Timer(self._api, 'Flows pause'):
                     self._api._traffic_item.PauseStatelessTrafficBlocking(True)
@@ -521,41 +519,29 @@ class TrafficItem(CustomField):
         flow_rows = {}
         for traffic_item in self._api.select_traffic_items(
                 traffic_item_filters=[filter]).values():
-            flow_row = {}
-            self._set_result_value(flow_row, 'name', traffic_item['name'])
-            self._set_result_value(flow_row, 'transmit',
-                                   self._get_state(traffic_item['state']))
-            self._set_result_value(
-                flow_row, 'port_tx',
-                traffic_item['highLevelStream'][0]['txPortName'])
-            self._set_result_value(
-                flow_row, 'port_rx',
-                ' '.join(traffic_item['highLevelStream'][0]['rxPortNames']))
-            flow_rows[traffic_item['name']] = flow_row
+            for stream in traffic_item['highLevelStream']:
+                flow_row = {}
+                self._set_result_value(flow_row, 'name', traffic_item['name'])
+                self._set_result_value(flow_row, 'transmit',
+                                    self._get_state(stream['state']))
+                self._set_result_value(
+                    flow_row, 'port_tx',
+                    stream['txPortName'])
+                self._set_result_value(
+                    flow_row, 'port_rx',
+                    ' '.join(stream['rxPortNames']))
+                for external_name, _, external_type in self._RESULT_COLUMNS:
+                    self._set_result_value(flow_row, external_name, 0, external_type)
+                flow_rows[flow_row['name'] + flow_row['port_tx'] + flow_row['port_rx']] = flow_row
         try:
             table = self._api.assistant.StatViewAssistant(
                 'Flow Statistics')
             table.AddRowFilter('Traffic Item', StatViewAssistant.REGEX,
                                filter['regex'])
             for row in table.Rows:
-                flow_row = flow_rows[row['Traffic Item']]
-                self._set_result_value(flow_row, 'port_tx', row['Tx Port'])
-                self._set_result_value(flow_row, 'port_rx', row['Rx Port'])
-                self._set_result_value(flow_row, 'frames_tx', row['Tx Frames'],
-                                       int)
-                self._set_result_value(flow_row, 'frames_rx', row['Rx Frames'],
-                                       int)
-                self._set_result_value(flow_row, 'bytes_rx', row['Rx Bytes'],
-                                       int)
-                self._set_result_value(flow_row, 'frames_tx_rate',
-                                       row['Tx Frame Rate'], float)
-                self._set_result_value(flow_row, 'frames_rx_rate',
-                                       row['Rx Frame Rate'], float)
-                self._set_result_value(flow_row, 'bytes_tx_rate',
-                                       row['Tx Rate (Bps)'], float)
-                self._set_result_value(flow_row, 'bytes_rx_rate',
-                                       row['Rx Rate (Bps)'], float)
-                self._set_result_value(flow_row, 'loss', row['Loss %'], float)
+                flow_row = flow_rows[row['Traffic Item'] + row['Tx Port'] + row['Rx Port']]
+                for external_name, internal_name, external_type in self._RESULT_COLUMNS:
+                    self._set_result_value(flow_row, external_name, row[internal_name], external_type)
         except Exception as e:
             self._api.add_error(e)
         return flow_rows.values()
